#ifndef COUNTER_H
#define COUNTER_H

#include <QObject>
#include <QDate>

class Counter : public QObject
{
public:
    Counter();

    QString Description;
    QString Type;
    QString Class;
    QString Code;

    QString Unita;
    int SogliaDisplayType;
    float Soglia;
    float Utilizzato;
    float Residuo;
    float Scatto;
    QString DimensioneScatto;
    QDate Periodo;
    QDate DataUtile;

    QString ToString();
    bool FromString(QString string);
};

#endif // COUNTER_H
